summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/bstring.h
diff options
context:
space:
mode:
Diffstat (limited to 'kfile-plugins/torrent/bstring.h')
-rw-r--r--kfile-plugins/torrent/bstring.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kfile-plugins/torrent/bstring.h b/kfile-plugins/torrent/bstring.h
index 81b1b0b0..c51311fc 100644
--- a/kfile-plugins/torrent/bstring.h
+++ b/kfile-plugins/torrent/bstring.h
@@ -19,8 +19,8 @@
#ifndef _BSTRING_H
#define _BSTRING_H
-#include <qstring.h>
-#include <qcstring.h>
+#include <tqstring.h>
+#include <tqcstring.h>
#include "bytetape.h"
#include "bbase.h"
@@ -45,7 +45,7 @@ class BString : public BBase
* @param start the position in the buffer to start
* reading from
*/
- BString (QByteArray &dict, int start = 0);
+ BString (TQByteArray &dict, int start = 0);
/**
* Construct a BString from @p tape. Any changes made to
@@ -67,14 +67,14 @@ class BString : public BBase
virtual ~BString ();
/**
* Returns a QString representation of the data in the
* BString. It is the responsibility of the caller to ensure
* that the data is convertible to a QString. More specifically,
* the data should not contain any embedded NULLs.
*
* @return QString containing the data from this BString.
*/
- QString get_string() const { return QString::fromUtf8(m_data.data()); }
+ TQString get_string() const { return TQString::fromUtf8(m_data.data()); }
/**
* Returns the amount of data held by the string. It would be
@@ -104,20 +104,20 @@ class BString : public BBase
/**
* Outputs the b-encoded representation of the object to the given
* QIODevice.
* @param device the QIODevice to write to
* @return true on a successful write, false otherwise
*/
- virtual bool writeToDevice (QIODevice &device);
+ virtual bool writeToDevice (TQIODevice &device);
/**
* Changes the value of the string to the given QString.
*
* @param str the QString containing the new value
* @return true if the value was successfully changed,
* false otherwise.
*/
- bool setValue (const QString &str);
+ bool setValue (const TQString &str);
private:
@@ -129,7 +129,7 @@ class BString : public BBase
*/
void init (ByteTape &tape);
- QByteArray m_data;
+ TQByteArray m_data;
bool m_valid;
};
@@ -67,14 +67,14 @@ class BString : public BBase
virtual ~BString ();
/**
- * Returns a QString representation of the data in the
+ * Returns a TQString representation of the data in the
* BString. It is the responsibility of the caller to ensure
@@ -67,14 +67,14 @@ class BString : public BBase
* BString. It is the responsibility of the caller to ensure
- * that the data is convertible to a QString. More specifically,
+ * that the data is convertible to a TQString. More specifically,
* the data should not contain any embedded NULLs.
*
@@ -67,14 +67,14 @@ class BString : public BBase
* the data should not contain any embedded NULLs.
*
- * @return QString containing the data from this BString.
+ * @return TQString containing the data from this BString.
*/
@@ -104,20 +104,20 @@ class BString : public BBase
/**
* Outputs the b-encoded representation of the object to the given
- * QIODevice.
- * @param device the QIODevice to write to
+ * TQIODevice.
+ * @param device the TQIODevice to write to
* @return true on a successful write, false otherwise
*/
@@ -104,20 +104,20 @@ class BString : public BBase
/**
- * Changes the value of the string to the given QString.
+ * Changes the value of the string to the given TQString.
*
@@ -104,20 +104,20 @@ class BString : public BBase
*
- * @param str the QString containing the new value
+ * @param str the TQString containing the new value
* @return true if the value was successfully changed,
* false otherwise.